@@ -7,7 +7,6 @@ $region Spain
 
 import logging
 import re
-from urllib.parse import urlparse
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
@@ -20,35 +19,33 @@ log = logging.getLogger(__name__)
 
 
 @pluginmatcher(re.compile(
-    r"https?://(?:www\.)?atresplayer\.com/",
+    r"https?://(?:www\.)?atresplayer\.com/directos/.+",
 ))
 class AtresPlayer(Plugin):
+    _channels_api_url = "https://api.atresplayer.com/client/v1/info/channels"
+    _player_api_url = "https://api.atresplayer.com/player/v1/live/{channel_id}"
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.url = update_scheme("https://", f"{self.url.rstrip('/')}/")
 
     def _get_streams(self):
-        path = urlparse(self.url).path
-        api_url = self.session.http.get(self.url, schema=validate.Schema(
-            re.compile(r"""window.__PRELOADED_STATE__\s*=\s*({.*?});""", re.DOTALL),
-            validate.none_or_all(
-                validate.get(1),
-                validate.parse_json(),
-                {"links": {path: {"href": validate.url()}}},
-                validate.get(("links", path, "href")),
-            ),
-        ))
-        if not api_url:
-            return
-        log.debug(f"API URL: {api_url}")
-
-        player_api_url = self.session.http.get(api_url, schema=validate.Schema(
+        channel_path = f"/{self.url.split('/')[-2]}/"
+        channel_data = self.session.http.get(self._channels_api_url, schema=validate.Schema(
             validate.parse_json(),
-            {"urlVideo": validate.url()},
-            validate.get("urlVideo"),
+            [{
+                "id": str,
+                "link": {"url": str},
+            }],
+            validate.filter(lambda item: item["link"]["url"] == channel_path),
         ))
+        if not channel_data:
+            return
+        channel_id = channel_data[0]["id"]
 
+        player_api_url = self._player_api_url.format(channel_id=channel_id)
         log.debug(f"Player API URL: {player_api_url}")
+
         sources = self.session.http.get(player_api_url, acceptable_status=(200, 403), schema=validate.Schema(
             validate.parse_json(),
             validate.any(
